==> gatsby-theme-heimr-0.52.1.tgz: package/gatsby-config.js <==
const path = require('path')

module.exports = ({ manifest = {}, sitemap = {}, siteUrl, matomoSiteId }) => ({
  siteMetadata: {
    name: 'TODO',
    description: 'TODO',
    menuItems: [
      {
        title: 'Hem',
        link: '/',
      },
    ],
    siteUrl: 'TODO',
  },
  assetPrefix: '/assets',
  plugins: [
    'gatsby-plugin-resolve-src',
    'gatsby-plugin-react-helmet',
    'gatsby-plugin-sass',
    'gatsby-plugin-sharp',
    {
      resolve: '@danbruegge/gatsby-plugin-stylelint',
      options: { files: ['**/*.{js,jsx,css,scss}'] },
    },
    {
      resolve: 'gatsby-source-filesystem',
      options: {
        name: 'images',
        path: 'src/images',
      },
    },
    'gatsby-transformer-sharp',
    {
      resolve: 'gatsby-plugin-manifest',
      options: {
        name: manifest.name,
        short_name: manifest.short_name,
        start_url: manifest.start_url || '/',
        background_color: manifest.background_color,
        theme_color: manifest.theme_color,
        display: manifest.display || 'standalone',
        icon: manifest.icon || 'src/images/icon.png',
      },
    },
    {
      resolve: 'gatsby-plugin-sitemap',
      options: {
        serialize: ({ site, allSitePage }) =>
          allSitePage.edges.map((edge) => {
            return {
              url: site.siteMetadata.siteUrl + edge.node.path,
              changefreq: sitemap.changeFrequency || 'monthly',
              priority: 1.0,
            }
          }),
      },
    },
    {
      resolve: 'gatsby-plugin-asset-path',
      options: {
        // js and css is default.
        // map is to move css.map files
        // png is to move favicons and such
        fileTypes: ['js', 'css', 'map', 'png'],
      },
    },
    {
      resolve: `gatsby-plugin-canonical-urls`,
      options: {
        siteUrl: siteUrl,
      },
    },
    {
      resolve: 'gatsby-plugin-matomo',
      options: {
        siteId: matomoSiteId,
        matomoUrl: 'https://matomo.accodeing.com',
        siteUrl: siteUrl,
      },
    },
  ],
})

==> gatsby-theme-heimr-0.57.1.tgz: package/gatsby-config.js <==
const path = require('path')

module.exports = ({ manifest = {}, sitemap = {}, siteUrl, matomoSiteId }) => ({
  siteMetadata: {
    name: 'TODO',
    description: 'TODO',
    menuItems: [
      {
        title: 'Hem',
        link: '/',
      },
    ],
    siteUrl: 'TODO',
  },
  assetPrefix: '/assets',
  plugins: [
    'gatsby-plugin-resolve-src',
    'gatsby-plugin-react-helmet',
    'gatsby-plugin-sass',
    'gatsby-plugin-sharp',
    {
      resolve: '@danbruegge/gatsby-plugin-stylelint',
      options: { files: ['**/*.{css,scss}'] },
    },
    {
      resolve: 'gatsby-source-filesystem',
      options: {
        name: 'images',
        path: 'src/images',
      },
    },
    'gatsby-transformer-sharp',
    {
      resolve: 'gatsby-plugin-manifest',
      options: {
        name: manifest.name,
        short_name: manifest.short_name,
        start_url: manifest.start_url || '/',
        background_color: manifest.background_color,
        theme_color: manifest.theme_color,
        display: manifest.display || 'standalone',
        icon: manifest.icon || 'src/images/icon.png',
      },
    },
    {
      resolve: 'gatsby-plugin-sitemap',
      options: {
        serialize: ({ site, allSitePage }) =>
          allSitePage.edges.map((edge) => {
            return {
              url: site.siteMetadata.siteUrl + edge.node.path,
              changefreq: sitemap.changeFrequency || 'monthly',
              priority: 1.0,
            }
          }),
      },
    },
    {
      resolve: 'gatsby-plugin-asset-path',
      options: {
        // js and css is default.
        // map is to move css.map files
        // png is to move favicons and such
        fileTypes: ['js', 'css', 'map', 'png'],
      },
    },
    {
      resolve: `gatsby-plugin-canonical-urls`,
      options: {
        siteUrl: siteUrl,
      },
    },
    {
      resolve: 'gatsby-plugin-matomo',
      options: {
        siteId: matomoSiteId,
        matomoUrl: 'https://matomo.accodeing.com',
        siteUrl: siteUrl,
      },
    },
  ],
})
